@@ -362,15 +362,15 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
             rows from a request, before limit (Snowflake)
         """
         df = self.get_df(data_source, permissions)
-        if limit is not None:
-            return DataSlice(
-                df[offset : offset + limit],
-                stats=DataStats(total_returned_rows=len(df), total_rows=len(df)),
-            )
-        else:
-            return DataSlice(
-                df[offset:], stats=DataStats(total_returned_rows=len(df), total_rows=len(df))
-            )
+        truncated_df = df[offset : offset + limit] if limit is not None else df[offset:]
+        return DataSlice(
+            truncated_df,
+            stats=DataStats(
+                total_returned_rows=len(df),
+                total_rows=len(df),
+                df_memory_size=df.memory_usage().sum(),
+            ),
+        )
 
     def explain(self, data_source: ToucanDataSource, permissions: Optional[dict] = None):
         """Method to give metrics about the query"""
